/**
Mapping of predefined entity names to their replacement values.

@type {Readonly<{[name: string]: string}>}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#sec-predefined-ent
*/
export const predefinedEntities: Readonly<{
    [name: string]: string;
}>;
/**
Returns `true` if _char_ is an XML `NameChar`, `false` if it isn't.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#NT-NameChar
*/
export function isNameChar(char: string): boolean;
/**
Returns `true` if _char_ is an XML `NameStartChar`, `false` if it isn't.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#NT-NameStartChar
*/
export function isNameStartChar(char: string): boolean;
/**
Returns `true` if _char_ is not a valid XML `Char`, `false` otherwise.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#NT-Char
*/
export function isNotXmlChar(char: string): boolean;
/**
Returns `true` if _char_ is a valid reference character (which may appear
between `&` and `;` in a reference), `false` otherwise.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#sec-references
*/
export function isReferenceChar(char: string): boolean;
/**
Returns `true` if _char_ is an XML whitespace character, `false` otherwise.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#white
*/
export function isWhitespace(char: string): boolean;
/**
Returns `true` if _char_ is a valid XML `Char`, `false` otherwise.

@param {string} char
@returns {boolean}
@see https://www.w3.org/TR/2008/REC-xml-20081126/#NT-Char
*/
export function isXmlChar(char: string): boolean;
//# sourceMappingURL=syntax.d.ts.map